@@ -21,11 +21,9 @@
 # pylint: disable=import-error
 """Global Qubes Config tool."""
 import sys
-import threading
 from typing import Dict, Optional, List, Union
 from html import escape
 import pkg_resources
-import subprocess
 import logging
 
 import qubesadmin
@@ -34,6 +32,7 @@ import qubesadmin.exc
 import qubesadmin.vm
 from ..widgets.gtk_utils import show_error, show_dialog, load_theme
 from ..widgets.gtk_widgets import ProgressBarDialog, ViewportHandler
+from ..widgets.utils import open_url_in_disposable
 from .page_handler import PageHandler
 from .policy_handler import PolicyHandler, VMSubsetPolicyHandler
 from .policy_rules import RuleSimple, \
@@ -206,6 +205,20 @@ class GlobalConfig(Gtk.Application):
         self.perform_setup()
         assert self.main_window
         self.main_window.show()
+        # resize to screen size
+        if self.main_window.get_allocated_width() > \
+                self.main_window.get_screen().get_width():
+            width = int(self.main_window.get_screen().get_width() * 0.9)
+        else:
+            # try to have at least 1100 pixels
+            width = min(int(self.main_window.get_screen().get_width() * 0.9),
+                        1100)
+        if self.main_window.get_allocated_height() > \
+                self.main_window.get_screen().get_height() * 0.9:
+            height = int(self.main_window.get_screen().get_height() * 0.9)
+        else:
+            height = self.main_window.get_allocated_height()
+        self.main_window.resize(width, height)
         self.hold()
 
     @staticmethod
@@ -244,7 +257,7 @@ class GlobalConfig(Gtk.Application):
         self.builder.add_from_file(pkg_resources.resource_filename(
             'qubes_config', 'global_config.glade'))
 
-        self.main_window = self.builder.get_object('main_window')
+        self.main_window: Gtk.Window = self.builder.get_object('main_window')
         self.main_notebook: Gtk.Notebook = \
             self.builder.get_object('main_notebook')
 
@@ -351,6 +364,7 @@ class GlobalConfig(Gtk.Application):
         self.progress_bar_dialog.hide()
         self.progress_bar_dialog.destroy()
 
+
     def _usbvm_changed(self, *_args):
         response = show_dialog(
             parent=self.main_window, title=_("USB qube change"),
@@ -378,18 +392,9 @@ class GlobalConfig(Gtk.Application):
             label.connect("activate-link", self._activate_link)
 
     def _activate_link(self, _widget, url):
-        open_thread = threading.Thread(group=None,
-                                       target=self._open_url_in_dvm, args=[url])
-        open_thread.start()
+        open_url_in_disposable(url, self.qapp)
         return True
 
-    def _open_url_in_dvm(self, url):
-        default_dvm = self.qapp.default_dispvm
-        subprocess.run(
-            ['qvm-run', '-p', '--service', f'--dispvm={default_dvm}',
-             'qubes.OpenURL'], input=url.encode(), check=False,
-            stderr=subprocess.DEVNULL, stdout=subprocess.DEVNULL)
-
     def get_current_page(self) -> Optional[PageHandler]:
         """Get currently visible page."""
         page_num = self.main_notebook.get_current_page()
